@@ -1,4 +1,4 @@
-import { FieldProcessorAdt, FieldSchema } from '@ephox/boulder';
+import { FieldProcessor, FieldSchema } from '@ephox/boulder';
 import { Arr, Fun } from '@ephox/katamari';
 
 import { AlloyBehaviourRecord, derive, NamedConfiguredBehaviour } from '../behaviour/Behaviour';
@@ -7,19 +7,19 @@ export interface SketchBehaviours {
   dump: AlloyBehaviourRecord;
 }
 
-const field = (name: string, forbidden: Array<{ name: () => string }>): FieldProcessorAdt =>
+const field = (name: string, forbidden: Array<{ name: () => string }>): FieldProcessor =>
   FieldSchema.defaultedObjOf(name, { }, Arr.map(
     forbidden,
     (f) => FieldSchema.forbid(f.name(), 'Cannot configure ' + f.name() + ' for ' + name)
   ).concat([
-    FieldSchema.state('dump', Fun.identity)
+    FieldSchema.customField('dump', Fun.identity)
   ]));
 
 const get = (data: SketchBehaviours): AlloyBehaviourRecord => data.dump;
 
 const augment = (data: SketchBehaviours, original: Array<NamedConfiguredBehaviour<any, any, any>>): AlloyBehaviourRecord => ({
-  ...data.dump,
-  ...derive(original)
+  ...derive(original),
+  ...data.dump
 });
 
 // Is this used?
