@@ -1,3 +1,5 @@
+import { Fun } from '@ephox/katamari';
+
 export interface BehaviourState {
   /** This is for debug purposes only, and only used by the Alloy Inspector Chrome Plugin */
   readState: () => any;
@@ -9,9 +11,7 @@ export interface BehaviourStateInitialiser<C, S extends BehaviourState> {
 
 const NoState: BehaviourStateInitialiser<any, BehaviourState> = {
   init: () => nu({
-    readState: () => {
-      return 'No State required';
-    }
+    readState: Fun.constant('No State required')
   })
 };
 
