@@ -1,21 +1,21 @@
-import { FieldProcessorAdt, FieldSchema, ValueSchema } from '@ephox/boulder';
+import { FieldProcessor, FieldSchema, ValueType } from '@ephox/boulder';
 
 import * as Boxes from '../../alien/Boxes';
 import * as Fields from '../../data/Fields';
 
 export default [
   FieldSchema.optionObjOf('contextual', [
-    FieldSchema.strictString('fadeInClass'),
-    FieldSchema.strictString('fadeOutClass'),
-    FieldSchema.strictString('transitionClass'),
-    FieldSchema.strictFunction('lazyContext'),
+    FieldSchema.requiredString('fadeInClass'),
+    FieldSchema.requiredString('fadeOutClass'),
+    FieldSchema.requiredString('transitionClass'),
+    FieldSchema.requiredFunction('lazyContext'),
     Fields.onHandler('onShow'),
     Fields.onHandler('onShown'),
     Fields.onHandler('onHide'),
     Fields.onHandler('onHidden')
   ]),
   FieldSchema.defaultedFunction('lazyViewport', Boxes.win),
-  FieldSchema.defaultedArrayOf('modes', [ 'top', 'bottom' ], ValueSchema.string),
+  FieldSchema.defaultedArrayOf('modes', [ 'top', 'bottom' ], ValueType.string),
   Fields.onHandler('onDocked'),
   Fields.onHandler('onUndocked')
-] as FieldProcessorAdt[];
\ No newline at end of file
+] as FieldProcessor[];
\ No newline at end of file
