@@ -1,11 +1,11 @@
-import { FieldProcessorAdt } from '@ephox/boulder';
+import { FieldProcessor } from '@ephox/boulder';
 
 import DragStarting from '../../dragging/dragndrop/DragStarting';
 import Dropping from '../../dragging/dragndrop/Dropping';
 
 const ex: {
-  drag: FieldProcessorAdt[];
-  drop: FieldProcessorAdt[];
+  drag: FieldProcessor[];
+  drop: FieldProcessor[];
 } = {
   drag: DragStarting,
   drop: Dropping
