@@ -3,8 +3,8 @@ import { FieldSchema } from '@ephox/boulder';
 import * as Fields from '../../data/Fields';
 
 export default [
-  FieldSchema.strict('highlightClass'),
-  FieldSchema.strict('itemClass'),
+  FieldSchema.required('highlightClass'),
+  FieldSchema.required('itemClass'),
 
   Fields.onHandler('onHighlight'),
   Fields.onHandler('onDehighlight')
