@@ -1,6 +1,6 @@
 import { FieldSchema } from '@ephox/boulder';
 
 export default [
-  FieldSchema.strict('onPinch'),
-  FieldSchema.strict('onPunch')
+  FieldSchema.required('onPinch'),
+  FieldSchema.required('onPunch')
 ];
