@@ -1,4 +1,4 @@
-import { FieldProcessorAdt, FieldSchema } from '@ephox/boulder';
+import { FieldSchema } from '@ephox/boulder';
 import { Fun } from '@ephox/katamari';
 
 import * as Behaviour from '../../api/behaviour/Behaviour';
@@ -7,9 +7,9 @@ import { SketchBehaviours } from '../../api/component/SketchBehaviours';
 import * as PartType from '../../parts/PartType';
 import { CustomListDetail } from '../types/CustomListTypes';
 
-const schema: () => FieldProcessorAdt[] = Fun.constant([
+const schema = Fun.constant([
   FieldSchema.defaulted('shell', false),
-  FieldSchema.strict('makeItem'),
+  FieldSchema.required('makeItem'),
   FieldSchema.defaulted('setupItem', Fun.noop),
   SketchBehaviours.field('listBehaviours', [ Replacing ])
 ]);
