@@ -1,6 +1,7 @@
-import { FieldSchema, ValueSchema } from '@ephox/boulder';
+import { FieldSchema, StructureSchema, ValueType } from '@ephox/boulder';
 import { Optional, Result } from '@ephox/katamari';
-import { FormComponentWithLabel, FormComponentWithLabelSpec, formComponentWithLabelFields } from './FormComponent';
+
+import { FormComponentWithLabel, formComponentWithLabelFields, FormComponentWithLabelSpec } from './FormComponent';
 
 export interface InputSpec extends FormComponentWithLabelSpec {
   type: 'input';
@@ -25,9 +26,9 @@ const inputFields = formComponentWithLabelFields.concat([
   FieldSchema.defaultedBoolean('disabled', false)
 ]);
 
-export const inputSchema = ValueSchema.objOf(inputFields);
+export const inputSchema = StructureSchema.objOf(inputFields);
 
-export const inputDataProcessor = ValueSchema.string;
+export const inputDataProcessor = ValueType.string;
 
-export const createInput = (spec: InputSpec): Result<Input, ValueSchema.SchemaError<any>> =>
-  ValueSchema.asRaw<Input>('input', inputSchema, spec);
+export const createInput = (spec: InputSpec): Result<Input, StructureSchema.SchemaError<any>> =>
+  StructureSchema.asRaw<Input>('input', inputSchema, spec);
