@@ -1,4 +1,5 @@
-import { FieldProcessorAdt, FieldSchema } from '@ephox/boulder';
+import { FieldProcessor, FieldSchema } from '@ephox/boulder';
+
 import { BodyComponent, BodyComponentSpec } from './BodyComponent';
 
 export interface LabelSpec {
@@ -13,8 +14,8 @@ export interface Label {
   items: BodyComponent[];
 }
 
-export const createLabelFields = (itemsField: FieldProcessorAdt): FieldProcessorAdt[] => [
-  FieldSchema.strictString('type'),
-  FieldSchema.strictString('label'),
+export const createLabelFields = (itemsField: FieldProcessor): FieldProcessor[] => [
+  FieldSchema.requiredString('type'),
+  FieldSchema.requiredString('label'),
   itemsField
 ];
