@@ -1,14 +1,15 @@
-import { FieldSchema, Processor, ValueSchema } from '@ephox/boulder';
+import { FieldSchema, StructureProcessor, StructureSchema } from '@ephox/boulder';
 import { Arr } from '@ephox/katamari';
+
 import { DialogSpec } from '../components/dialog/Dialog';
 import { getDataProcessor, getNamedItems } from './DataProcessors';
 
-export const createDataValidator = <T>(structure: DialogSpec<T>): Processor => {
+export const createDataValidator = <T>(structure: DialogSpec<T>): StructureProcessor => {
   const namedItems = getNamedItems(structure);
   const fields = Arr.bind(namedItems, (item) => getDataProcessor(item).fold(
     () => [],
-    (schema) => [ FieldSchema.strictOf(item.name, schema) ]
+    (schema) => [ FieldSchema.requiredOf(item.name, schema) ]
   ));
 
-  return ValueSchema.objOf(fields);
+  return StructureSchema.objOf(fields);
 };
