@@ -1,4 +1,4 @@
-import { Fun, Thunk } from '@ephox/katamari';
+import { Fun, Optional, Thunk } from '@ephox/katamari';
 
 import { Browser as BrowserCore } from '../core/Browser';
 import { OperatingSystem as OperatingSystemCore } from '../core/OperatingSystem';
@@ -13,7 +13,8 @@ const mediaMatch = (query: string) => window.matchMedia(query).matches;
 
 // IMPORTANT: Must be in a thunk, otherwise rollup thinks calling this immediately
 // causes side effects and won't tree shake this away
-let platform = Thunk.cached(() => PlatformDetection.detect(navigator.userAgent, mediaMatch));
+// Note: navigator.userAgentData is not part of the native typescript types yet
+let platform = Thunk.cached(() => PlatformDetection.detect(navigator.userAgent, Optional.from(((navigator as any).userAgentData)), mediaMatch));
 
 export const detect = (): PlatformDetection => platform();
 
