@@ -9,4 +9,5 @@ import Editor from '../api/Editor';
 import * as Rtc from '../Rtc';
 import { Content, SetContentArgs } from './ContentTypes';
 
-export const setContent = (editor: Editor, content: Content, args: SetContentArgs = {}): Content => Rtc.setContent(editor, content, args);
+export const setContent = (editor: Editor, content: Content, args: SetContentArgs = {}): Content =>
+  Rtc.setContent(editor, content, args);
