@@ -6,11 +6,9 @@
  */
 
 import Editor from 'tinymce/core/api/Editor';
-import { EmojiDatabase } from '../core/EmojiDatabase';
-import * as Dialog from './Dialog';
 
-const register = (editor: Editor, database: EmojiDatabase): void => {
-  const onAction = () => Dialog.open(editor, database);
+const register = (editor: Editor): void => {
+  const onAction = () => editor.execCommand('mceEmoticons');
 
   editor.ui.registry.addButton('emoticons', {
     tooltip: 'Emoticons',
