@@ -6,10 +6,11 @@
  */
 
 import { Arr, Obj } from '@ephox/katamari';
+
 import Env from 'tinymce/core/api/Env';
 
 // Converts shortcut format to Mac/PC variants
-const convertText = (source: string) => {
+const convertText = (source: string): string => {
   const mac = {
     alt: '&#x2325;',
     ctrl: '&#x2303;',
