@@ -6,9 +6,14 @@
  */
 
 import { Dialog } from 'tinymce/core/api/ui/Ui';
+
 import { CustomTabSpecs } from '../Plugin';
 
-const get = (customTabs: CustomTabSpecs) => {
+export interface Api {
+  readonly addTab: (spec: Dialog.TabSpec) => void;
+}
+
+const get = (customTabs: CustomTabSpecs): Api => {
   const addTab = (spec: Dialog.TabSpec): void => {
     const currentCustomTabs = customTabs.get();
     currentCustomTabs[spec.name] = spec;
