@@ -12,11 +12,14 @@ export const enum ListType {
   UL = 'ul'
 }
 
-const isList = (el: SugarElement) => Compare.is(el, 'OL,UL');
+const isList = (el: SugarElement<Node>): el is SugarElement<HTMLOListElement | HTMLUListElement> =>
+  Compare.is(el, 'OL,UL');
 
-const hasFirstChildList = (el: SugarElement) => Traverse.firstChild(el).map(isList).getOr(false);
+const hasFirstChildList = (el: SugarElement<HTMLElement>): boolean =>
+  Traverse.firstChild(el).exists(isList);
 
-const hasLastChildList = (el: SugarElement) => Traverse.lastChild(el).map(isList).getOr(false);
+const hasLastChildList = (el: SugarElement<HTMLElement>): boolean =>
+  Traverse.lastChild(el).exists(isList);
 
 export {
   isList,
