@@ -7,17 +7,19 @@
 
 import Editor from 'tinymce/core/api/Editor';
 
-const register = (editor: Editor) => {
+const register = (editor: Editor): void => {
+  const onAction = () => editor.execCommand('mceNonBreaking');
+
   editor.ui.registry.addButton('nonbreaking', {
     icon: 'non-breaking',
     tooltip: 'Nonbreaking space',
-    onAction: () => editor.execCommand('mceNonBreaking')
+    onAction
   });
 
   editor.ui.registry.addMenuItem('nonbreaking', {
     icon: 'non-breaking',
     text: 'Nonbreaking space',
-    onAction: () => editor.execCommand('mceNonBreaking')
+    onAction
   });
 };
 
