@@ -8,7 +8,7 @@
 import Editor from 'tinymce/core/api/Editor';
 import Env from 'tinymce/core/api/Env';
 
-const register = (editor: Editor) => {
+const register = (editor: Editor): void => {
   editor.addCommand('mcePrint', () => {
     // TINY-3762 IE will print the current window instead of the iframe window
     // however using execCommand appears to make it print from the correct window
