@@ -8,22 +8,12 @@
 import { Arr } from '@ephox/katamari';
 import { TableConversions, TableLookup, Warehouse } from '@ephox/snooker';
 import { Attribute, Css, SugarElement } from '@ephox/sugar';
-import Editor from 'tinymce/core/api/Editor';
-import * as TableSize from '../queries/TableSize';
-
-const enforcePercentage = (editor: Editor, table: SugarElement<HTMLTableElement>) => {
-  const tableSizing = TableSize.get(editor, table);
-  TableConversions.convertToPercentSize(table, tableSizing);
-};
-
-const enforcePixels = (editor: Editor, table: SugarElement<HTMLTableElement>) => {
-  const tableSizing = TableSize.get(editor, table);
-  TableConversions.convertToPixelSize(table, tableSizing);
-};
 
+const enforcePercentage = TableConversions.convertToPercentSize;
+const enforcePixels = TableConversions.convertToPixelSize;
 const enforceNone = TableConversions.convertToNoneSize;
 
-const syncPixels = (table: SugarElement<HTMLTableElement>) => {
+const syncPixels = (table: SugarElement<HTMLTableElement>): void => {
   const warehouse = Warehouse.fromTable(table);
   if (!Warehouse.hasColumns(warehouse)) {
     // Ensure the specified width matches the actual cell width
@@ -35,5 +25,10 @@ const syncPixels = (table: SugarElement<HTMLTableElement>) => {
   }
 };
 
-export { enforcePercentage, enforcePixels, enforceNone, syncPixels };
+export {
+  enforcePercentage,
+  enforcePixels,
+  enforceNone,
+  syncPixels
+};
 
