@@ -6,11 +6,13 @@
  */
 
 import { Cell } from '@ephox/katamari';
+
 import Editor from 'tinymce/core/api/Editor';
+
 import * as Settings from '../api/Settings';
 import * as VisualBlocks from './VisualBlocks';
 
-const setup = (editor: Editor, pluginUrl: string, enabledState: Cell<boolean>) => {
+const setup = (editor: Editor, pluginUrl: string, enabledState: Cell<boolean>): void => {
   // Prevents the visualblocks from being presented in the preview of formats when that is computed
   editor.on('PreviewFormats AfterPreviewFormats', (e) => {
     if (enabledState.get()) {
