@@ -6,9 +6,10 @@
  */
 
 import Editor from 'tinymce/core/api/Editor';
+
 import { WordCountApi } from './Api';
 
-const fireWordCountUpdate = (editor: Editor, api: WordCountApi) => {
+const fireWordCountUpdate = (editor: Editor, api: WordCountApi): void => {
   editor.fire('wordCountUpdate', {
     wordCount: {
       words: api.body.getWordCount(),
@@ -20,4 +21,4 @@ const fireWordCountUpdate = (editor: Editor, api: WordCountApi) => {
 
 export {
   fireWordCountUpdate
-};
\ No newline at end of file
+};
